@@ -839,7 +839,7 @@ class mothe:
                         print(keypoints)
                         clone = frame.copy()
                         for point in keypoints:
-                            cv2.rectangle(clone, (point[0]-grab_size, point[1]-grab_size), (point[0]+grab_size, point[1]+grab_size), (0, 255, 0), 2)
+                            cv2.rectangle(clone, (point[0]-(grab_size/2), point[1]-(grab_size/2)), (point[0]+(grab_size/2), point[1]+(grab_size/2)), (0, 255, 0), 2)
 
                 elif key == 27:
                     i = (nframes)
@@ -852,7 +852,7 @@ class mothe:
                         cv2.imwrite(path + "/" + self.class_name + "/" + "{}-{}-f{}-k{}.jpg".format(self.movie_name, self.class_name, i, enum), crop_img)
                     break
                 for point in keypoints:
-                    cv2.rectangle(clone, (point[0]-grab_size, point[1]-grab_size), (point[0]+grab_size, point[1]+grab_size), (0, 255, 0), 2)
+                    cv2.rectangle(clone, (point[0]-(grab_size/2), point[1]-(grab_size/2)), (point[0]+(grab_size/2), point[1]+(grab_size)/2), (0, 255, 0), 2)
             cv2.destroyAllWindows()
 
     
